purchases_dart library
Classes
- ErrorInterceptor
- ErrorInterceptor for handling errors in Dio, and converting them to custom exceptions.
- PurchasesBackend
- Backend for Purchases.
- PurchasesDart
- Entry point for PurchasesDart.
- PurchasesDartConfiguration
- Configuration object used when calling PurchasesDart.configure to configure the PurchasesDart plugin.
- PurchasesHeader
- Header configuration for Purchases API requests.
- RawCustomer
- RawEntitlementObject
- RawOffering
- RawOfferings
- RawPackage
- RawSubscriptionObject
Functions
-
entitlementsFromJson(
Map< String, dynamic> ? json) → List<RawEntitlementObject> -
nonSubscriptionsFromJson(
Map< String, dynamic> ? json, [bool onlyLatestPurchases = false]) → List<RawSubscriptionObject> -
subscriptionsFromJson(
Map< String, dynamic> ? json) → List<RawSubscriptionObject>
Exceptions / Errors
- BadRequestException
- Exception thrown when a bad request (HTTP 400) is received from the server.
- CertificateVerificationFailed
- Exception thrown when SSL/TLS certificate verification fails.
- ConflictException
- Exception thrown when a conflict (HTTP 409) occurs.
- ConnectionTimeOutException
- Exception thrown when a connection timeout occurs.
- InternalServerErrorException
- Exception thrown when an internal server error (HTTP 500) occurs.
- NoInternetConnectionException
- Custom Exceptions Exception thrown when there is no internet connection available.
- NotFoundException
- Exception thrown when a resource is not found (HTTP 404).
- ReceiveTimeOutException
- Exception thrown when a receive timeout occurs.
- SendTimeOutException
- Exception thrown when a send timeout occurs.
- Exception thrown when an unauthorized request (HTTP 401) is made.